SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

BEGIN;

DELETE FROM cc_monitor_process_polling_mst WHERE sub_platform_id = 'cloudn_flat' OR sub_platform_id = 'cloudn_vpc';

COMMIT;

BEGIN;

DELETE FROM cc_monitor_process_method_mst WHERE sub_platform_id = 'cloudn_flat' OR sub_platform_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP
--\http://docs.aws.amazon.com/general/latest/gr/rande.html
DELETE FROM cc_cloud_endpoint WHERE cloud_service_id = 'cloudn_flat' OR cloud_service_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP

DELETE FROM cc_cloud_region WHERE cloud_service_id = 'cloudn_flat' OR cloud_service_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP

DELETE FROM cc_cloud_service WHERE cloud_service_id = 'cloudn_flat' OR cloud_service_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP

DELETE FROM cc_cloud_type_mst WHERE cloud_id = 'cloudn_flat' OR cloud_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP

DELETE FROM cc_collector_platform_mst WHERE platform_id = 'cloudn_flat' OR platform_id = 'cloudn_vpc';

COMMIT;

BEGIN;

--\set ON_ERROR_STOP

DELETE FROM cc_collector_sub_platform_mst WHERE sub_platform_id = 'cloudn_flat' OR sub_platform_id = 'cloudn_vpc';

COMMIT;